Discriminability
****************

.. currentmodule:: hyppo.discrim

Discriminability One Sample Test
--------------------------------
.. autoclass:: DiscrimOneSample

Discriminability Two Sample Test
--------------------------------
.. autoclass:: DiscrimTwoSample
